GFAnimation class

Inheritance

Constructors

GFAnimation({Key? key, required Widget child, Duration? duration, Alignment? alignment, Curve? curve, GFAnimationType? type, double? width, double? height, Color? activeColor, Color? color, EdgeInsetsGeometry? padding, Alignment? activeAlignment, void onTap()?, EdgeInsetsGeometry? margin, Animation<double>? turnsAnimation, Animation<double>? scaleAnimation, AnimationController? controller, TextDirection? textDirection, Animation<Offset>? slidePosition, TextStyle? style, TextAlign? textAlign, TextOverflow? textOverflow, int? maxLines, TextWidthBasis? textWidthBasis, double? fontSize, FontWeight? fontWeight, double? changedWidth, double? changedHeight, Duration? reverseDuration})
Wrap any widget with GFAnimation to animate your widget. see GFAnimationType for types of animations.
const

Properties

activeAlignment → Alignment?
Defines how the animated widget is aligned(after the onTap) during Animation.
final
activeColor → Color?
defines the color of AnimatedContainer when onTap triggers
final
alignment → Alignment?
Defines how the animated widget is aligned during Animation.
final
changedHeight → double?
defines the height of AnimatedContainer upto which it can expand during animation
final
changedWidth → double?
defines the width of AnimatedContainer upto which it can expand during animation
final
child → Widget
The child of type Widget to display animation effect.
final
color → Color?
defines the color of AnimatedContainer
final
controller → AnimationController?
Type of AnimationController, its a controller of an animation.
final
curve → Curve?
Determines the animation curve. Defaults to Curves.linear.
final
duration → Duration?
The duration for animation to perform
final
fontSize → double?
Defines the fontSize of AnimatedDefaultTextStyle
final
fontWeight → FontWeight?
Defines the fontWeight of AnimatedDefaultTextStyle
final
hashCode → int
The hash code for this object.
no setterinherited
height → double?
defines AnimatedContainer initial height
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
margin → EdgeInsetsGeometry?
defines child's or AnimatedContainer margin
final
maxLines → int?
Defines the maxLines of AnimatedDefaultTextStyle
final
onTap → void Function()?
Called when the user taps the child
final
padding → EdgeInsetsGeometry?
defines child's or AnimatedContainer padding
final
reverseDuration → Duration?
The duration for reverse animation to perform
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scaleAnimation → Animation<double>?
For GFAnimationType.scaleTransition, customized scale animation can be added to ScaleTransition widget
final
slidePosition → Animation<Offset>?
For GFAnimationType.slideTransition, which animates the position of a widget.
final
style → TextStyle?
Defines the TextStyle of AnimatedDefaultTextStyle
final
textAlign → TextAlign?
Defines the TextAlign of AnimatedDefaultTextStyle
final
textDirection → TextDirection?
Defines direction of the AnimatedDefaultTextStyle TextDirection i.e ltr,rtl
final
textOverflow → TextOverflow?
Defines the TextOverflow of AnimatedDefaultTextStyle
final
textWidthBasis → TextWidthBasis?
Defines the TextWidthBasis of AnimatedDefaultTextStyle
final
turnsAnimation → Animation<double>?
For GFAnimationType.rotateTransition, customized turns animation can be added to RotationTransition widget
final
type → GFAnimationType?
type of GFAnimation which takes the type ie, align, size, container, rotateTransition, scaleTransition, slideTransition, and textStyle for the GFAnimation
final
width → double?
defines AnimatedContainer initial width
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _GFAnimationState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited