GFAvatar class

Inheritance

Constructors

GFAvatar({Key? key, Widget? child, Color? backgroundColor, ImageProvider<Object>? backgroundImage, Color? foregroundColor, double? radius, double? minRadius, double? maxRadius, BorderRadius? borderRadius, GFAvatarShape shape = GFAvatarShape.circle, double size = GFSize.MEDIUM})
Create Avatar of all types i,e, square, circle, standard with different sizes.
const

Properties

backgroundColor → Color?
use Color or GFColors. The color with which to fill the circle.
final
backgroundImage → ImageProvider<Object>?
The background image of the circle.
final
borderRadius → BorderRadius?
border radius to give extra radius for avatar square or standard shape Not applicable to circleshape
final
child → Widget?
Typically a Text widget. If the CircleAvatar is to have an image, use backgroundImage instead.
final
foregroundColor → Color?
use Color or GFColors. The default text color for text in the circle.
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
maxRadius → double?
The maximum size of the avatar, expressed as the radius (half the diameter).
final
minRadius → double?
The minimum size of the avatar, expressed as the radius (half the diameter).
final
radius → double?
The size of the avatar, expressed as the radius (half the diameter).
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shape → GFAvatarShape
shape of avatar GFAvatarShape i.e, standard, circle, square
final
size → double
size of avatar. use GFSize or double i.e, 1.2, small, medium, large etc.
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited