GFBorder class

Inheritance

Constructors

GFBorder({required Widget child, Color color = Colors.black, double strokeWidth = 1, GFBorderType type = GFBorderType.rect, List<double> dashedLine = const <double>[3, 1], EdgeInsets padding = const EdgeInsets.all(10), Radius radius = const Radius.circular(0)})
Create different types of borders around given child widget

Properties

child → Widget
child of type Widget which can be any component or text, etc
final
color → Color
color of type Color or GFColor which is used to change the color of the border type
final
dashedLine → List<double>
dashedLine of type List<double> which is used for the linear and simple dashed line of border
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
padding → EdgeInsets
padding for child where in padding is given to the border types
final
radius → Radius
radius of type Radius used to give a curved border only when the border type is RRect, in other cases radius will not work
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
strokeWidth → double
storkeWidth of type double which is used to define the thickness of the border
final
type → GFBorderType
type of GFBorderType which is used to define the different types of borders ie, circle, Rect, RRect and oval
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited