GFButtonBar class

Inheritance

Constructors

GFButtonBar({Key? key, Axis direction = Axis.horizontal, WrapAlignment alignment = WrapAlignment.center, double spacing = 8.0, WrapAlignment runAlignment = WrapAlignment.start, double runSpacing = 0.0, WrapCrossAlignment crossAxisAlignment = WrapCrossAlignment.start, TextDirection? textDirection, VerticalDirection verticalDirection = VerticalDirection.down, required List<Widget> children, EdgeInsetsGeometry padding = const EdgeInsets.all(0)})
Create buttons bar for all types of buttons. check GFButton and GFIconButton
const

Properties

alignment → WrapAlignment
How the children within a run should be placed in the main axis.
final
children → List<Widget>
The buttons to arrange horizontally. Typically GFButton or GFIconButton widgets.
final
crossAxisAlignment → WrapCrossAlignment
How the children within a run should be aligned relative to each other in the cross axis.
final
direction → Axis
The direction to use as the main axis.
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
padding → EdgeInsetsGeometry
The empty space that surrounds the buttonBar. Default's to padding.zero
final
runAlignment → WrapAlignment
How the runs themselves should be placed in the cross axis.
final
runSpacing → double
How much space to place bestuckValue the runs themselves in the cross axis.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
spacing → double
How much space to place bestuckValue children in a run in the main axis.
final
textDirection → TextDirection?
Determines the order to lay children out horizontally and how to interpret start and end in the horizontal direction.
final
verticalDirection → VerticalDirection
Determines the order to lay children out vertically and how to interpret start and end in the vertical direction.
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited