GFIconButton class

Inheritance

Constructors

GFIconButton({Key? key, double iconSize = 0.0, EdgeInsetsGeometry padding = const EdgeInsets.all(8), AlignmentGeometry alignment = Alignment.center, required Widget icon, Color? focusColor, Color? hoverColor, Color? highlightColor, Color? splashColor, Color? disabledColor, required VoidCallback? onPressed, FocusNode? focusNode, bool autofocus = false, String? tooltip, GFButtonType type = GFButtonType.solid, GFIconButtonShape shape = GFIconButtonShape.standard, Color color = GFColors.PRIMARY, ShapeBorder? borderShape, BoxShadow? boxShadow, double size = GFSize.MEDIUM, bool? buttonBoxShadow, BorderSide? borderSide})
Create icon buttons of all types. check out GFButton for buttons
const

Properties

alignment → AlignmentGeometry
Defines how the icon is positioned within the IconButton.
final
autofocus → bool
True if this widget will be selected as the initial focus when no other node in its scope is currently focused.
final
borderShape → ShapeBorder?
The shape and border for the button's Material.
final
borderSide → BorderSide?
The border side for the button's Material.
final
boxShadow → BoxShadow?
The box shadow for the button's Material, if GFButtonType is solid
final
buttonBoxShadow → bool?
on true state default box shadow appears around button, if GFButtonType is solid
final
color → Color
Pass GFColors or Color
final
disabledColor → Color?
Pass GFColors or Color. The color to use for the icon inside the button, if the icon is disabled.
final
focusColor → Color?
The color for the button's icon when it has the input focus.
final
focusNode → FocusNode?
An optional focus node to use as the focus node for this widget.
final
hashCode → int
The hash code for this object.
no setterinherited
highlightColor → Color?
Pass GFColors or Color. The secondary color of the button when the button is in the down (pressed) state.
final
hoverColor → Color?
The color for the button's icon when a pointer is hovering over it.
final
icon → Widget
The icon to display inside the button.
final
iconSize → double
The size of the icon inside the button.
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onPressed → VoidCallback?
The callback that is called when the button is tapped or otherwise activated.
final
padding → EdgeInsetsGeometry
The padding around the button's icon.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shape → GFIconButtonShape
Button type of GFIconButtonShape i.e, standard, pills, square, shadow, icons
final
size → double
size of double or GFSize i.e, 1.2, small, medium, large etc.
final
splashColor → Color?
Pass GFColors or Color. The primary color of the button when the button is in the down (pressed) state.
final
tooltip → String?
Text that describes the action that will occur when the button is pressed.
final
type → GFButtonType
Button type of GFButtonType i.e, solid, outline, outline2x transparent
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _GFIconButtonState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited