GfMultiChipSelectData class

Inheritance

Constructors

GfMultiChipSelectData({required List<String> values, TextStyle? lableStyle, Color? selectedColor, Color? unselectedColor, List<int>? preselected})

Properties

chipsdata ↔ List<ChipData>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hasListeners → bool
Whether any listeners are currently registered.
no setterinherited
lableStyle ↔ TextStyle?
getter/setter pair
preselected ↔ List<int>?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectedColor ↔ Color?
getter/setter pair
unselectedColor ↔ Color?
getter/setter pair
values → List<String>
final

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
dispose() → void
Discards any resources used by the object.
inherited
getlist() → List<ChipData>
getlistselected() → List<String>
getlistselectedindx() → List<int>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
onSelected({required int index, required bool value}) → Future<void>
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited