GfFormHandler class

Inheritance

Constructors

GfFormHandler({required GlobalKey<FormState> formsKey})

Properties

formsKey → GlobalKey<FormState>
final
hashCode → int
The hash code for this object.
no setterinherited
hasListeners → bool
Whether any listeners are currently registered.
no setterinherited
models ↔ List<ChangeNotifier>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
dispose() → void
Discards any resources used by the object.
inherited
getFormValues() → Future<List>
getModels() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
setModel(ChangeNotifier modelx) → void
toString() → String
A string representation of this object.
inherited
validateForm() → Future<bool>

Operators

operator ==(Object other) → bool
The equality operator.
inherited