GFLoader class

Inheritance

Constructors

GFLoader({Key? key, Color loaderColorOne = Colors.redAccent, Color loaderColorTwo = Colors.green, Color loaderColorThree = Colors.blueAccent, Duration duration = const Duration(milliseconds: 1000), GFLoaderType type = GFLoaderType.android, Widget? loaderIconOne, Widget? loaderIconTwo, Widget? loaderIconThree, Animation<Color>? androidLoaderColor, double loaderstrokeWidth = 4.0, double size = GFSize.MEDIUM, Widget? child})
GFLoader shows differnt type of loaders with different customization options.
const

Properties

androidLoaderColor → Animation<Color>?
type of Animation
final
child → Widget?
Type of Widget used only in custom type and it is prominent over the loaderIconOne, loaderIconTwo, loaderIconThree in custom type
final
duration → Duration
Type of duration which defines the animation duration of the loader only in circle and square type of loader
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
loaderColorOne → Color
Type of GFColor or Color which defines the color of the first dot in only circle or square type of loader
final
loaderColorThree → Color
Type of GFColor or Color which defines the color of the third dot in only circle or square type of loader
final
loaderColorTwo → Color
Type of GFColor or Color which defines the color of the second dot in only circle or square type of loader
final
loaderIconOne → Widget?
Type of Widget which takes text, icons or images for first dot only in custom type of loader
final
loaderIconThree → Widget?
Type of Widget which takes text, icons or images for third dot only in custom type of loader
final
loaderIconTwo → Widget?
Type of Widget which takes text, icons or images for second dot only in custom type of loader
final
loaderstrokeWidth → double
type of double used to change the stroke width of the android loader only
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → double
type of double or GFSize ie, small , medium or large which is used to change the size of android, ios, circle and square loaders only
final
type → GFLoaderType
Type of GFLoaderType ie, android, ios, circle , square and custom
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _GFLoaderState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited