GFProgressBar class

Inheritance

Constructors

GFProgressBar({Key? key, EdgeInsets? margin = const EdgeInsets.only(left: 10, right: 10), double percentage = 0.2, double circleWidth = 5.0, double circleStartAngle = 0.0, double? radius, Color backgroundColor = const Color(0xFFB8C7CB), Color progressBarColor = Colors.red, LinearGradient? linearGradient, bool animation = false, int animationDuration = 700, Widget? child, bool autoLive = true, bool animateFromLastPercentage = false, bool reverse = false, MaskFilter? mask, GFProgressType type = GFProgressType.linear, GFProgressHeadType? progressHeadType, double lineHeight = 5.0, double? width, bool fromRightToLeft = false, Widget? leading, Widget? trailing, EdgeInsets? padding, MainAxisAlignment alignment = MainAxisAlignment.start, bool clipLinearGradient = false, bool? isDragable = false, ValueChanged<double>? onProgressChanged})
Shows progress as a completed and remaining percentage in bar of given state

Properties

alignment → MainAxisAlignment
type of MainAxisAlignment used to align the leading, trailing and the progress bar in a fashion
final
animateFromLastPercentage → bool
set true if you want to animate the progress bar from the last percentage value you set
final
animation → bool
type of bool which allows the progress line to animate when the percentage values are changed
final
animationDuration → int
duration of the animation in milliseconds, It only applies if animation attribute is true
final
autoLive → bool
set false if you don't want to preserve the state of the widget
final
backgroundColor → Color
type of Color or GFColors used to change the backgroundColor of the progress bar
final
child → Widget?
type of Widget which can be text , icon etc which is generally used to show the percentage of progress complete
final
circleStartAngle → double
type of double in which the angle on the circle starts to progress (in degrees, eg: 0.0, 45.0, 90.0)
final
circleWidth → double
type of double which defines the thickness of the circle's arc in Circular Progress bar
final
clipLinearGradient → bool
Set true if you want to display only part of linearGradient based on progressPercent value If no linearGradient is specified this option is ignored.
final
fromRightToLeft → bool
set true if you want to animate the linear bar from the right to left
final
hashCode → int
The hash code for this object.
no setterinherited
isDragable → bool?
set true if you want the change this progressbar value this feature is only available for linear progress type
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
leading → Widget?
type of Widget which comes before the progress bar
final
linearGradient → LinearGradient?
If present, this will make the progress bar colored by this gradient. This will override progressBarColor. It is an error to provide both.
final
lineHeight → double
Height of the Progress Bar
final
margin → EdgeInsets?
type of EdgeInsets which gives margin to the GFProgressBar
final
mask → MaskFilter?
Creates a mask filter that takes the progress shape being drawn and blurs it.
final
onProgressChanged → ValueChanged<double>?
return the current value of progressbar to get latest value please set isDragable field to true this feature is only available for linear progress type
final
padding → EdgeInsets?
type of EdgeInsets which gives padding to the GFProgressBar
final
percentage → double
type of double which should be from 0 to 1 to indicate the progress of the ProgressBars
final
progressBarColor → Color
type of Color , used to change the color of the active progress line
final
progressHeadType → GFProgressHeadType?
type of GFProgressHeadType which changes the shape of progress head based on the type ie, circular and square
final
radius → double?
type of double used to show the radius of Circular Progress Bar
final
reverse → bool
type of bool used to display the progress in reverse direction
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
trailing → Widget?
type of Widget which comes after the progress bar
final
type → GFProgressType
type of GFProgressType which changes the shape of progress bar based on the type ie, circular and linear
final
width → double?
width of the Progress bar
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _GFProgressBarState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited