GFRating class

Inheritance

Constructors

GFRating({Key? key, required RatingChangeCallback onChanged, required double value, int itemCount = 5, double spacing = 0.0, Widget? defaultIcon, Color? color, Color? borderColor, double size = GFSize.MEDIUM, Widget? filledIcon, Widget? halfFilledIcon, bool allowHalfRating = true, bool showTextForm = false, Widget? suffixIcon, TextEditingController? controller, InputDecoration? inputDecorations, EdgeInsets margin = const EdgeInsets.symmetric(vertical: 16), EdgeInsets padding = const EdgeInsets.symmetric(horizontal: 16)})
GFRating to show ratings with many custimazation options.
const

Properties

allowHalfRating → bool
if true, allow half rating of items on dragging. Default it will be in true state
final
borderColor → Color?
defines the border color of halfFilledIcon
final
color → Color?
defines the color of items
final
controller → TextEditingController?
controls the TextField Controller of rating TextFormField
final
defaultIcon → Widget?
defines the default items, when having filledIcon && halfFilledIcon
final
filledIcon → Widget?
defines the items when filled
final
halfFilledIcon → Widget?
defines the items when half-filled
final
hashCode → int
The hash code for this object.
no setterinherited
inputDecorations → InputDecoration?
defines the InputDecoration of rating TextFormField
final
itemCount → int
defines total number of rating items
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
margin → EdgeInsets
defines the margin of rating TextFormField
final
onChanged → RatingChangeCallback
return current rating whenever rating is updated
final
padding → EdgeInsets
defines the padding of rating TextFormField
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showTextForm → bool
if true, shows rating TextFormField with the rating bar, that allows the user input to show rating
final
size → double
defines the size of items. GFSize can be used for size variations like small. medium. large
final
spacing → double
defines the space bestuckValue items
final
suffixIcon → Widget?
defines the design and funtion of rating TextFormField's suffix icon
final
value → double
defines the rating value
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _GFRatingState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited