GFStickyHeaderBuilder class

Inheritance

Constructors

GFStickyHeaderBuilder({Key? key, required StickyHeaderWidgetBuilder stickyContentBuilder, required Widget content, Axis direction = Axis.vertical, bool enableHeaderOverlap = false, RenderGFStickyHeaderCallback? callback, GFPosition stickyContentPosition = GFPosition.start})
Place this widget inside a ListView, GridView, CustomScrollView, SingleChildScrollView or similar. Constructs a new GFStickyHeaderBuilder widget.
const

Properties

callback → RenderGFStickyHeaderCallback?
Allows to add custom stickyHeader stuck offset value
final
content → Widget
widget can be used to define content.
final
direction → Axis
direction allows children to align in vertical / horizontal way Defaults to Axis.vertical
final
enableHeaderOverlap → bool
On state true, the stickyContentBuilder will overlap the content. Only works when direction is Axis.vertical. Default set to false.
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stickyContentBuilder → StickyHeaderWidgetBuilder
builder widget can be used to define stickyContentBuilder.
final
stickyContentPosition → GFPosition
GFPosition allows to stickyContentPosition to stick at top in Axis.vertical and stick at start in Axis.horizontal Defaults to GFPosition.start
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _GFStickyHeaderBuilderState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited