GFTabBar class

A material design widget that displays a horizontal row of tabs.

Typically created as the AppBar.bottom part of an AppBar and in conjunction with a TabBarView.

Inheritance

Constructors

GFTabBar({Key? key, required int? length, required List<Widget> tabs, required TabController? controller, bool isScrollable = false, double? tabBarHeight, Color? tabBarColor, Color? indicatorColor, double indicatorWeight = 2.0, EdgeInsetsGeometry indicatorPadding = EdgeInsets.zero, Decoration? indicator, TabBarIndicatorSize? indicatorSize, Color? labelColor, TextStyle? labelStyle, EdgeInsetsGeometry? labelPadding, Color? unselectedLabelColor, TextStyle? unselectedLabelStyle, ShapeBorder? shape, double? width})
Creates a material design tab bar. The tabs argument must not be null and its length must match the controller's TabController.length.
const

Properties

controller → TabController?
This widget's selection and animation state.
final
hashCode → int
The hash code for this object.
no setterinherited
indicator → Decoration?
Defines the appearance of the selected tab indicator.
final
indicatorColor → Color?
The color of the line that appears below the selected tab.
final
indicatorPadding → EdgeInsetsGeometry
The horizontal padding for the line that appears below the selected tab.
final
indicatorSize → TabBarIndicatorSize?
Defines how the selected tab indicator's size is computed.
final
indicatorWeight → double
The thickness of the line that appears below the selected tab.
final
isScrollable → bool
Whether this tab bar can be scrolled horizontally.
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
labelColor → Color?
The color of selected tab labels.
final
labelPadding → EdgeInsetsGeometry?
The padding added to each of the tab labels.
final
labelStyle → TextStyle?
The text style of the selected tab labels.
final
length → int?
The total number of tabs. Typically greater than one. Must match TabBar.tabs's and TabBarView.children's length.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shape → ShapeBorder?
defines the shape of tabBar
final
tabBarColor → Color?
Sets TabBar color using material color Color
final
tabBarHeight → double?
Sets GFTabBar height
final
tabs → List<Widget>
Typically a list of two or more Tab widgets.
final
unselectedLabelColor → Color?
The color of unselected tab labels.
final
unselectedLabelStyle → TextStyle?
The text style of the unselected tab labels
final
width → double?
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _GFTabBarState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited