GFTextFieldSquared class

Inheritance

Constructors

GFTextFieldSquared({Key? key, required Color editingbordercolor, required Color idlebordercolor, required double borderwidth, required String hintText, Color? backgroundcolor, Widget? iconPrefix, Color normalbordercolor = Colors.grey, Color focusedbordercolor = Colors.green, Color errorbordercolor = Colors.red, Color disabledbordercolor = Colors.black, double paddingvertical = 3, double paddinghorizontal = 4, double marginvertical = 3, double marginhorizontal = 4, TextEditingController? controller, String initialValue = '', FocusNode? focusNode, TextInputType? keyboardType = TextInputType.text, TextCapitalization textCapitalization = TextCapitalization.none, TextInputAction? textInputAction, TextStyle? style = const TextStyle(), StrutStyle? strutStyle = const StrutStyle(), TextDirection? textDirection = TextDirection.ltr, TextAlign? textAlign = TextAlign.start, TextAlignVertical? textAlignVertical = TextAlignVertical.center, bool autofocus = false, bool? readOnly = false, bool? showCursor, String obscuringCharacter = '.', bool obscureText = false, bool autocorrect = true, SmartDashesType? smartDashesType, SmartQuotesType? smartQuotesType, bool enableSuggestions = true, bool? autovalidate = true, MaxLengthEnforcement maxLengthEnforced = MaxLengthEnforcement.none, int? maxLines = 1, int? minLines = 1, bool expands = true, int? maxLength, ValueChanged<String>? onChanged, GestureTapCallback? onTap, VoidCallback? onEditingComplete, ValueChanged<String>? onFieldSubmitted, FormFieldSetter<String>? onSaved, FormFieldValidator<String>? validator, List<TextInputFormatter>? inputFormatters, bool enabled = true, double? cursorWidth = 2.0, double? cursorHeight, Radius? cursorRadius, Color? cursorColor, Color? color, Radius? borderradius, Brightness? keyboardAppearance, EdgeInsets scrollPadding = const EdgeInsets.all(20), bool enableInteractiveSelection = true, InputCounterWidgetBuilder? buildCounter, ScrollPhysics? scrollPhysics, Iterable<String>? autofillHints, AutovalidateMode autoValidateMode = AutovalidateMode.disabled})
const

Properties

autocorrect → bool
final
autofillHints → Iterable<String>?
final
autofocus → bool
final
autovalidate → bool?
final
autoValidateMode → AutovalidateMode
final
backgroundcolor → Color?
final
borderradius → Radius?
final
borderwidth → double
final
buildCounter → InputCounterWidgetBuilder?
final
color → Color?
final
controller → TextEditingController?
final
cursorColor → Color?
final
cursorHeight → double?
final
cursorRadius → Radius?
final
cursorWidth → double?
final
disabledbordercolor → Color
final
editingbordercolor → Color
final
enabled → bool
final
enableInteractiveSelection → bool
final
enableSuggestions → bool
final
errorbordercolor → Color
final
expands → bool
final
focusedbordercolor → Color
final
focusNode → FocusNode?
final
hashCode → int
The hash code for this object.
no setterinherited
hintText → String
final
iconPrefix → Widget?
final
idlebordercolor → Color
final
initialValue → String
final
inputFormatters → List<TextInputFormatter>?
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
keyboardAppearance → Brightness?
final
keyboardType → TextInputType?
final
marginhorizontal → double
final
marginvertical → double
final
maxLength → int?
final
maxLengthEnforced → MaxLengthEnforcement
final
maxLines → int?
final
minLines → int?
final
normalbordercolor → Color
final
obscureText → bool
final
obscuringCharacter → String
final
onChanged → ValueChanged<String>?
final
onEditingComplete → VoidCallback?
final
onFieldSubmitted → ValueChanged<String>?
final
onSaved → FormFieldSetter<String>?
final
onTap → VoidCallback?
final
paddinghorizontal → double
final
paddingvertical → double
final
readOnly → bool?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scrollPadding → EdgeInsets
final
scrollPhysics → ScrollPhysics?
final
showCursor → bool?
final
smartDashesType → SmartDashesType?
final
smartQuotesType → SmartQuotesType?
final
strutStyle → StrutStyle?
final
style → TextStyle?
final
textAlign → TextAlign?
final
textAlignVertical → TextAlignVertical?
final
textCapitalization → TextCapitalization
final
textDirection → TextDirection?
final
textInputAction → TextInputAction?
final
validator → FormFieldValidator<String>?
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _GFTextFieldSquaredState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited