ToastView class

Constructors

ToastView()
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

overlayState ↔ OverlayState?
getter/setter pair

Static Methods

createView(String text, BuildContext context, int? toastDuration, GFToastPosition? toastPosition, Color backgroundColor, TextStyle textStyle, double toastBorderRadius, Border? border, dynamic trailing) → void
dismiss() → Future<void>