GFShimmerDirection enum

GFShimmerDirection controls the direction of the shimmer effect

Inheritance
Available extensions

Values

leftToRight → const GFShimmerDirection

Default direction is GFShimmerDirection.leftToRight, which starts the shimmer effect animation from left to right side of the child Widget.

rightToLeft → const GFShimmerDirection

Direction GFShimmerDirection.rightToLeft, which starts the shimmer effect animation from right to left side of the child Widget.

topToBottom → const GFShimmerDirection

Direction GFShimmerDirection.topToBottom, which starts the shimmer effect animation from top to bottom side of the child Widget.

bottomToTop → const GFShimmerDirection

Direction GFShimmerDirection.bottomToTop, which starts the shimmer effect animation from bottom to top side of the child Widget.

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<GFShimmerDirection>
A constant List of the values in this enum, in order of their declaration.